#!/bin/ksh
# ident @(#)configuration.cgi	1.36     96/10/09 SMI
#
# Copyright 1996 Sun Microsystems, Inc. All Rights Reserved

MODULE=services/SUNWsbuA
. /opt/netra/SUNWnetra/lib/netra.globals
. $MODLIB/globals
. $MODLIB/legato.ksh

#
# check for configuration/reconfiguration setup
#
if [[ -a $RECONFIG_FILE ]]; then
	initial_setup
	if [[ $? -eq 0 ]]; then
		rm $RECONFIG_FILE
	fi
fi

num_msg_line=0
backup_server=`uname -n`
client=`uname -n`
if [[ -s $CFG_FILE ]]; then
	netra_cf_read $CFG_FILE
fi

display_all=1
if [[ -n $backup_server ]]; then
	server=$backup_server
	if [[ $server != `uname -n` ]]; then
		display_all=0
	fi
else
	server=$client
fi

cgi_post="$UNCGI$MODCGI/configure-chk.cgi"
set +u

print_loop(){
	MIN=$1
	MAX=$2
	SELECTED=$3
	let i=$MIN
	while (( $i < MAX )); do
		if [[ $SELECTED == $i ]]; then
			print "<option selected> $i"
		else
			print "<option> $i"
		fi		    
		let i="i + 1"
	done
}

DEFAULT_DEVICE_ALL=`get_default_device 2>&1`
if [[ $DEFAULT_DEVICE_ALL = *"RPC error"* ]]; then
	# No daemons are running -- we can't do anything!
        netra_html_info "$NO_DAEMON_BANNER"
	netra_html_head "Configure Automated Backup"
	print "$NO_DAEMON_ERR"
	netra_html_tail -u $MODCGI/index.cgi \
			-h $UNCGI$MODCGI/index_help.cgi?op=configuration
	exit 0
fi

#
# Map jukebox name.  Jukeboxes are listed by different
# names in get_devices (where the name comes from
# /etc/LGTOuscsi/changers) vs. get_default_device
# (where the name comes from nsradmin).  So we have
# to reconcile those two names, and use the one from
# /etc/LGTOuscsi/changers since that's the one we'll
# need to get the information to pass to jb_config.
#
if [[ $DEFAULT_DEVICE_ALL = Jukebox* ]]; then
	# Get the scsidev string:
	jbmodel=${DEFAULT_DEVICE_ALL#Jukebox }
	port=` ${LEGATO_SBIN}/nsradmin -s $server -i - <<-EOF
			show "control port"
			print type: NSR jukebox; model: $jbmodel
	EOF
	`
	port=${port#*port: }
	port=${port%;}

	changers=` $DRVDIR/changers | grep $port `
	changers=${changers##*"Product <"}
	changers=${changers%%">"*}
	DEFAULT_DEVICE_ALL="Jukebox $changers"
fi

DEFAULT_DEVICE=${DEFAULT_DEVICE_ALL%%?bn *}

device_list=`get_devices`

#
# Output the HTML
#
netra_html_head "Configure Automated Backup"
cat <<- xxEOFxx
	<FORM METHOD="POST" ACTION="${cgi_post}"> 
	<TABLE>
xxEOFxx

#
# Client support
#
print "<TR><TH ALIGN=left>Server:</TH><TD>"
print "<INPUT TYPE=text name=backup_server value=$backup_server size=20></TD>"
print "<TD ALIGN=left>(host name for local or remote tape server)</TD></TR>"

#
# If we're a client (display_all = 0), then the server's name
# is all we should display.
#
if [[ $display_all != 0 ]]; then

#
# Set default tape device
#

print "<TR><TH ALIGN=left></TH>"
print "<TR><TH ALIGN=left>Tape Device:</TH><TD>"
if [[ $device_list = "" ]]; then
	print "None"
	DEFAULT_DEVICE=None
	DEFAULT_DEVICE_ALL=None
else
	print "<select NAME=device>"
	if [[ $DEFAULT_DEVICE_ALL = "" ]]; then
		DEFAULT_DEVICE="None"
		DEFAULT_DEVICE_ALL="None"
	else
		print -n "<option value=\"$DEFAULT_DEVICE\" selected>"
		print "$DEFAULT_DEVICE"
	fi
	print "$device_list" | while read device; do
		if [[ $device != ${DEFAULT_DEVICE}* ]]; then
			print "<option value=\"$device\">$device"
		fi
	done
	print "</select>"
fi
print "</TD>"
print "<TD ALIGN=left>(Currently $DEFAULT_DEVICE_ALL)</TD></TR>"

#
# Compression 
#
print "<TR>"
print "<TH ALIGN=left>Compression:</TH>"
echo $DEFAULT_DEVICE_ALL | grep "hbn" > /dev/null 2>&1
if [[ $? -eq 0 ]]; then
	print "<TD><INPUT TYPE=radio NAME=compression VALUE=yes> Yes
		<INPUT TYPE=radio NAME=compression VALUE=no checked> No</TD>"
else
	print "<TD><INPUT TYPE=radio NAME=compression VALUE=yes checked> Yes
		<INPUT TYPE=radio NAME=compression VALUE=no> No</TD>"
fi
print "</TR>"

#
# Default values for the backup schedule:
#
schedule=${SCHEDULE_NAME}
period="Week"
action="full incr incr incr incr incr incr"
override=""
start_time="midnight"
autostart="Disabled"
group="Default"
browse_policy="Month"

#
# Get the client info to see what backup schedule we're really running:
#
nsr_output=$( ${LEGATO_SBIN}/nsradmin -s $server -i - <<EOF
	print type:NSR client; name:$client
	quit
EOF )
if [[ $nsr_output != "No resources found*" ]]; then
	schedule=$( print "$nsr_output" | grep schedule \
		   | sed 's/.*: //' | sed 's/;$//' )
	browse_policy=$( print "$nsr_output" | grep "browse policy" \
		   | sed 's/.*: //' | sed 's/;$//' )
	group=$( print "$nsr_output" | grep "group" \
		   | sed 's/.*: //' | sed 's/;$//' )
fi

# FIXME -- all these nsradmin lines should be combined into one
# command, since nsradmin isn't the fastest program.
#
# Get the automated backup schedule we're using from legato.
# This is the schedule we'll use and/or modify.
#
nsr_output=$( ${LEGATO_SBIN}/nsradmin -s $server -i - <<EOF
	. type:NSR schedule; name:$schedule
	print
	quit
EOF )
if [[ $nsr_output != "No resources found*" ]]; then
	period=$( print "$nsr_output" | grep period \
		 | sed 's/.*: //' | sed 's/;$//' )

	# Backups are currently forced to weekly.
	if [[ $period = "Week" ]]; then
		action=$( print "$nsr_output" | grep action \
			 | sed 's/.*: //' | sed 's/;$//' )
		override=$( print "$nsr_output" | grep override \
			 | sed 's/.*: //' | sed 's/;$//' )
	else
		period="Week"
		action="full incr incr incr incr incr incr"
		override=""
	fi
fi

#
# Figure out which day the full backup is.
#
set -A daysofweek Sunday Monday Tuesday Wednesday Thursday Friday Saturday
set -A actiondays $action
full_day="Sunday"
let i=0
while [[ $i -lt ${#daysofweek[*]} ]]; do
	if [[ ${actiondays[$i]} = f* ]]; then
		full_day=${daysofweek[$i]}
		#break		# Take only the first full-backup day
	fi
	let i=$i+1
done

#
# Get the info for the current group -- this tells us whether we're
# currently set up to do automated backups or not.
# We only deal with group "Default", and only allow that group
# to be set through the HTML interface; the user sets up
# any other groups outside of our interface at his own risk.
#
nsr_output=$( ${LEGATO_SBIN}/nsradmin -s $server -i - <<EOF
	. type:NSR group; name:$group
	print
	quit
EOF )
if [[ $nsr_output != "No resources found*" ]]; then
	# We only take integral start times.  The start time line will
	# be in a format like: <<start time: "h:mm";>>
	# so use sed to peel off that part:
	start_time=$( print "$nsr_output" | grep "start time" \
		     | sed 's/.*: "//' | sed 's/:.*//' )
	# Now start_time is the integral hour in miltime.
	# Translate it into something more human readable:
	let i=$start_time		# get an integer equivalent
	if [[ $start_time = 0 ]]; then
		start_time="midnight"
	elif [[ $start_time = 12 ]]; then
		start_time="noon"
	elif [[ $i -gt 12 ]]; then
		let i=$i-12
		start_time="$i pm"
	else
		start_time="$start_time am"
	fi

	autostart=$( print "$nsr_output" | grep "autostart" \
		    | sed 's/.*: //' | sed 's/;$//' )
	# Don't bother to check schedule -- already checked it for "client".
fi

#
# automatic backup
# colspan=3
# FIXME: need to get the current schedule from networker
#
cat <<- xxEOFxx
	<TR>
	<TH ALIGN=left>Automatic Backup:</TH>
	<TD COLSPAN=2><TABLE BORDER=1>
xxEOFxx

if [[ $autostart = "Disabled" ]]; then
	print "<TD rowspan=3><INPUT TYPE=radio NAME=auto_backup VALUE=yes> Yes</TD>"
else
	print "<TD rowspan=3><INPUT TYPE=radio NAME=auto_backup VALUE=yes checked> Yes</TD>"
fi

cat <<- xxEOFxx
	<TH ALIGN=left>Backup Start time:</TD>
	<TD><select name=auto_time SIZE=2>
xxEOFxx

for hr in   "midnight" "1 am" "2 am" "3 am" "4 am" "5 am" "6 am" "7 am" \
	    "8 am" "9 am" "10 am" "11 am" "noon" "1 pm" "2 pm" "3 pm" \
	    "4 pm" "5 pm" "6 pm" "7 pm" "8 pm" "9 pm" "10 pm" "11 pm" ; do
	if [[ $start_time == $hr ]]; then
		print "<option selected> $hr"
	else
		print "<option> $hr"
	fi		    
done

cat <<- xxEOFxx
	    </select></TD>
	<TR>
	<TH ALIGN=left>Full Backup:</TD>
	<TD><select name=full_time SIZE=2>
xxEOFxx

for day in ${daysofweek[*]}; do
	print -n "<option"
	if [[ $day = $full_day ]]; then
		print -n " selected"
	fi
	print "> $day"
done

cat <<- xxEOFxx
	    </select> </TD>
	<TR>
	<TH ALIGN=left>Incremental Backup:</TD>
	<TD ALIGN=left>Every day except day of Full Backup</TD>
	<TR><TD COLSPAN=3>
xxEOFxx

if [[ $autostart = "Disabled" ]]; then
	print "<INPUT TYPE=radio NAME=auto_backup VALUE=no checked> No"
else
	print "<INPUT TYPE=radio NAME=auto_backup VALUE=no> No"
fi
print "</TD></TR></TABLE></TD></TR>"

#
# Set email users
# Currently disabled -- the default is root, which is aliased
# to go to the right place.
#
#DEFAULT_USERS=`get_notifications`
#print "<TR><TD><B>Email Notifications:</B><TD><INPUT TYPE=text NAME=notify_users VALUE=\"$DEFAULT_USERS\" SIZE=30> (ex. admin@netra.com)"

#
# OnLine index file duration
#

# Get currently defined policies -- hope the names are self-explanatory
nsr_output=$( ${LEGATO_SBIN}/nsradmin -s $server -i - <<EOF
	print type:NSR policy
	quit
EOF )
nsrstatus=$?
print "<TR><TH ALIGN=left>Online Index File Duration:<TD><select name=index_duration SIZE=2>"

if [[ $nsrstatus = 0 && $nsr_output != "No resources found*" ]]; then
	set -A policies $( print "$nsr_output" | grep name \
			  | sed 's/.*: //' | sed 's/;.*//' )
	set -A periods $( print "$nsr_output" | grep "period: " \
			  | sed 's/.*: //' | sed 's/;.*//' )
	set -A num_per $( print "$nsr_output" | grep "number of periods: " \
			  | sed 's/.*: //' | sed 's/;.*//' )
	let i=0
	while [[ $i -lt ${#policies[*]} ]]; do
		if [[ ${policies[$i]} = $browse_policy ]]; then
			selected=" selected"
		else
			selected=""
		fi
		print "<option$selected>${policies[$i]}"
		let i=$i+1
	done
	print "</select>"
else
	print_loop 1 13 0
	print "</select> (months)"
fi

#
# show # of lines in status screen
#
print "<TR><TH ALIGN=left>Message size on status screen:</TH>"
netra_is_int "$num_msg_line"
if [[ $? -ne 0 || -z $num_msg_line || $num_msg_line == "0" ]]; then
	print "<TD><INPUT TYPE=radio NAME=message VALUE=all checked> All <INPUT TYPE=radio NAME=message VALUE=last> Last <select name=num_msg_line SIZE=2>"
	print_loop 1 51
else
	print "<TD><INPUT TYPE=radio NAME=message VALUE=all> All <INPUT TYPE=radio NAME=message VALUE=last checked> Last <select name=num_msg_line SIZE=2>"
	print_loop 1 51 $num_msg_line
fi
print "</select> lines</TR>"

#
# show update interval
#
if [[ $msg_interval = "" ]]; then
	msg_interval="10 sec"
else
	# Now change msg_interval from int # seconds to number and unit:
	let secs=$msg_interval
	if [[ $secs < 60 ]]; then
		msg_interval="$secs sec"
	else
		let mins=$secs/60
		msg_interval="$mins min"
	fi
fi
print "<TR>"
print "<TH ALIGN=left>Update interval for status screen:</TH>"
set -A intervals "5 sec" "10 sec" "30 sec" "1 min" "5 min" "10 min"
print "<td><select name=msg_interval SIZE=2>"
let i=0
while (( $i < ${#intervals[*]} )); do
	if [[ ${intervals[$i]} = $msg_interval ]]; then
		print "<option selected>${intervals[$i]}"
	else
		print "<option>${intervals[$i]}"
	fi
	let i=i+1
done
print "</select></td></tr>"

fi	# end of $display_all != 0 clause

print "</TABLE>"

netra_html_tail -rs -u $MODCGI/index.cgi \
	-h $UNCGI$MODCGI/index_help.cgi?op=configuration

set -u
