#!/bin/ksh
# ident @(#)configure-chk.cgi	1.27     96/09/30 SMI
#
# Copyright 1996 Sun Microsystems, Inc. All Rights Reserved

MODULE=services/SUNWsbuA
. /opt/netra/SUNWnetra/lib/netra.globals
. $MODLIB/globals
. $MODLIB/legato.ksh

server=`uname -n`
client=$server

DEVICE_ERR="No tape loaded or drive offline.  Make sure tape drive is online and a tape is loaded for tape identification."
BUSY_ERR="Tape drive is busy.  Wait until tape drive is free for tape identification."

#
# Make sure the legato daemons are running, since if they aren't,
# we will be unsuccessful in changing any of these parameters
#
daemons=`get_daemon_list`
if [[ $daemons = "" ]]; then
	netra_html_info "$NO_DAEMON_BANNER"
fi

##########################
#
# set server
#
##########################
backup_server="$WWW_backup_server"
cfg_vars="backup_server"

#############################
#
# If we're a client ($WWW_backup_server != $server),
# automatically set auto-backup OFF.
#
#############################
if [[ $WWW_backup_server != $server ]]; then
	WWW_auto_backup="off"
fi

#############################
#
# schedule automatic backup
# WWW_auto_time -- 0-23 
# WWW_full_time -- Sunday - Saturday
#
#############################
if [[ $WWW_auto_backup = "yes" ]]; then
	# Map the time from human-readable form back to integral hours:
	if [[ $WWW_auto_time = "midnight" ]]; then
		WWW_auto_time=0
	elif [[ $WWW_auto_time = "noon" ]]; then
		WWW_auto_time=12
	elif [[ $WWW_auto_time = *pm ]]; then
		let WWW_auto_time="12 + ${WWW_auto_time%% pm}"
	elif [[ $WWW_auto_time = *am ]]; then
		WWW_auto_time=${WWW_auto_time%% am}
	fi
else
	WWW_auto_time=0
	WWW_full_time=0
fi

auto_backup="$WWW_auto_backup"
auto_time="$WWW_auto_time"
full_time="$WWW_full_time"
cfg_vars="$cfg_vars auto_backup auto_time full_time"

###################################
#
# change online index file duration
#
###################################
index_duration="$WWW_index_duration"
cfg_vars="$cfg_vars index_duration"

#############################
#
# change device & compression
#
#############################
# Error checking for tape drive offline and busy since we couldn't get
#	tape drive info until tape drive is free

echo "$WWW_device" | grep "offline" > /dev/null 2>&1
if [[ $? -eq 0 ]]; then
	netra_html_info $DEVICE_ERR
	exec configuration.cgi
fi
echo "$WWW_device" | grep "busy" > /dev/null 2>&1
if [[ $? -eq 0 ]]; then
	netra_html_info $BUSY_ERR
	exec configuration.cgi
fi
if [[ $WWW_device = None* ]] then
	device_name="None"
	device_type="None"
elif [[ $WWW_device = Jukebox* ]] then
	# it'll be something like: Jukebox EXB-210
	device_name="Jukebox"
	device_type=${WWW_device#Jukebox }
else
	# it'll be something like: /dev/rmt0 4mm
	if [[ $WWW_compression = no ]]; then
		suff=hbn
	else
		suff=cbn
	fi
	if [[ $WWW_device = *" "* ]]; then
		device_name=${WWW_device%% *}$suff
		device_type=${WWW_device#* }
	else
		device_name=${WWW_device}
		device_type=""
	fi
fi
cfg_vars="$cfg_vars device_name device_type"

##########################
#
# save # message lines displayed on status screen to conf file
#
##########################
if [[ $WWW_message == "last" ]]; then
	if [[ $WWW_num_msg_line == "" ]]; then
		WWW_num_msg_line=5
	fi
	num_msg_line="$WWW_num_msg_line"
else
	num_msg_line="all"
fi
cfg_vars="$cfg_vars num_msg_line"

##########################
#
# save update interval for the server-push nph-status screen
#
##########################
if [[ $WWW_msg_interval != "" ]]; then
	# update interval has to be stored and used in seconds (arg to sleep)
	# parse the value in terms of "sec" or "min"
	if [[ $WWW_msg_interval = *min ]]; then
		let msg_interval=${WWW_msg_interval%% *}*60
	else
		let msg_interval=${WWW_msg_interval%% *}
	fi
	# Would be more reliable if we took all the digits, e.g.
	# something like ${WWW_msg_interval%%(+(!([0-9])))},
	# but I can't seem to find the right ksh expression.
	cfg_vars="$cfg_vars msg_interval"
fi

netra_cf_write $CFG_FILE $cfg_vars

config -c

netra_html_success
netra_html_head "Configure Automated Backup Schedule"

cat <<- xxEOFxx 
<p><b>Warning: Be sure to save the system configuration information
via Netra/Diskette.</b>
xxEOFxx

netra_html_tail \
	-u $MODCGI/index.cgi \
	$MODCGI/configuration.cgi "Configure Automated Backup Schedule"
set -u
